@@ -14,6 +14,7 @@ class Robot():
         self.collections = {}
         self.speed  = 0.5
         self.last_picked = []
+        self.count_report = None
  
     @property
     def x(self):
@@ -189,7 +190,8 @@ class Robot():
         >>> bot.report("Counted 10 apples")
 
         """
-        self.report = msg
+        self.count_report = msg
+        print_success("🤔 {}".format(msg))
     
     def cell(self):
         return self.world_model.cells[self.x - 1][self.y - 1 ]
@@ -210,6 +212,7 @@ class Robot():
         else:
             print_error("Wall Already exists")
             self.world.js_call("error", ["Wall already exists"])
+            raise RuntimeError("Wall Already exists")
     
     def remove_wall(self):
         """Removes wall if there is  wall in front of robot 
@@ -225,6 +228,7 @@ class Robot():
         else:
             print_error("No Wall exists")
             self.world.js_call("error", ["No Wall exists"])
+            raise RuntimeError("No Wall exists")
 
 
     def set_trace(self, color='red'):
@@ -406,5 +410,6 @@ class Robot():
                         self.world.js_call('update_object', [self.x, self.y, val - 1])
         else:
             print_error("No Items to Pick.")
+            raise RuntimeError("No Items to Pick.")
             self.world.js_call('error', ["No Items to Pick"])
 
